@@ -1,13 +1,8 @@
-from PyObjCTools.TestSupport import *
-
 import SecurityInterface
+from PyObjCTools.TestSupport import TestCase, min_os_level
 
 
 class TestSFChooseIdentityTableCellView(TestCase):
     @min_os_level("10.13")
     def test_classes(self):
         SecurityInterface.SFChooseIdentityTableCellView
-
-
-if __name__ == "__main__":
-    main()
